@@ -20,9 +20,6 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const GObject = imports.gi.GObject;
-const Lang = imports.lang;
-
 const Application = imports.application;
 const OSMAccountDialog = imports.osmAccountDialog;
 const OSMEditDialog = imports.osmEditDialog;
@@ -32,22 +29,20 @@ const Utils = imports.utils;
 /* minimum zoom level at which to offer adding a location */
 var MIN_ADD_LOCATION_ZOOM_LEVEL = 16;
 
-var OSMEdit = new Lang.Class({
-    Name: 'OSMEdit',
-    Extends: GObject.Object,
+var OSMEdit = class OSMEdit {
 
-    _init: function() {
+    constructor() {
         this._osmConnection = new OSMConnection.OSMConnection();
         this._osmObject = null; // currently edited object
         this._username = Application.settings.get('osm-username');
         this._isSignedIn = this._username !== null && this._username.length > 0;
-    },
+    }
 
     get object() {
         return this._osmObject;
-    },
+    }
 
-    createEditDialog: function(parentWindow, place) {
+    createEditDialog(parentWindow, place) {
         let dialog = new OSMEditDialog.OSMEditDialog({
             transient_for: parentWindow,
             modal: true,
@@ -55,9 +50,9 @@ var OSMEdit = new Lang.Class({
         });
 
         return dialog;
-    },
+    }
 
-    createEditNewDialog: function(parentWindow, latitude, longitude) {
+    createEditNewDialog(parentWindow, latitude, longitude) {
         let dialog = new OSMEditDialog.OSMEditDialog({
             transient_for: parentWindow,
             modal: true,
@@ -67,9 +62,9 @@ var OSMEdit = new Lang.Class({
         });
 
         return dialog;
-    },
+    }
 
-    createAccountDialog: function(parentWindow, closeOnSignIn) {
+    createAccountDialog(parentWindow, closeOnSignIn) {
         let dialog = new OSMAccountDialog.OSMAccountDialog({
             transient_for: parentWindow,
             modal: true,
@@ -77,9 +72,9 @@ var OSMEdit = new Lang.Class({
         });
 
         return dialog;
-    },
+    }
 
-    fetchObject: function(place, callback, cancellable) {
+    fetchObject(place, callback, cancellable) {
         let osmType = Utils.osmTypeToString(place.osmType);
 
         /* reset currenly edited object */
@@ -88,88 +83,87 @@ var OSMEdit = new Lang.Class({
                      (function(success, status, osmObject, osmType) {
                          callback(success, status, osmObject, osmType);
                      }), cancellable);
-    },
+    }
 
-    uploadObject: function(object, type, comment, callback) {
+    uploadObject(object, type, comment, callback) {
         this._openChangeset(object, type, comment,
                             this._uploadObject.bind(this), callback);
-    },
+    }
 
-    _onChangesetOpened: function(success, status, changesetId, object, type,
-                                 action, callback) {
+    _onChangesetOpened(success, status, changesetId, object, type, action, callback) {
         if (success) {
             let osmType = Utils.osmTypeToString(type);
             action(object, osmType, changesetId, callback);
         } else {
             callback(false, status);
         }
-    },
+    }
 
-    _openChangeset: function(object, type, comment, action, callback) {
-        this._osmConnection.openChangeset(comment, (function(success, status, changesetId) {
+    _openChangeset(object, type, comment, action, callback) {
+        this._osmConnection.openChangeset(comment, (success, status, changesetId) => {
             this._onChangesetOpened(success, status, changesetId, object, type, action, callback);
-        }).bind(this));
-    },
+        });
+    }
 
-    _onObjectUploaded: function(success, status, response, changesetId, callback) {
+    _onObjectUploaded(success, status, response, changesetId, callback) {
         if (success)
             this._closeChangeset(changesetId, callback);
         else
             callback(false, status);
-    },
+    }
 
-    _uploadObject: function(object, type, changesetId, callback) {
+    _uploadObject(object, type, changesetId, callback) {
         this._osmObject = object;
-        this._osmConnection.uploadObject(object, type, changesetId, (function(success, status, response) {
+        this._osmConnection.uploadObject(object, type, changesetId, (success, status, response) => {
             this._onObjectUploaded(success, status, response, changesetId, callback);
-        }).bind(this));
-    },
+        });
+    }
 
-    deleteObject: function(object, type, comment, callback) {
+    deleteObject(object, type, comment, callback) {
         this._openChangeset(object, type, comment,
                             this._deleteObject.bind(this), callback);
-    },
+    }
 
-    _onObjectDeleted: function(success, status, response, changesetId, callback) {
+    _onObjectDeleted(success, status, response, changesetId, callback) {
         if (success)
             this._closeChangeset(changesetId, callback);
         else
             callback(false, status);
-    },
+    }
 
-    _deleteObject: function(object, type, changesetId, callback) {
+    _deleteObject(object, type, changesetId, callback) {
         this._osmObject = object;
-        this._osmConnection.deleteObject(object, type, changesetId, (function(success, status, response) {
+        this._osmConnection.deleteObject(object, type, changesetId, (success, status, response) => {
             this._onObjectDeleted(success, status, response, changesetId, callback);
-        }).bind(this));
-    },
+        });
+    }
 
-    _closeChangeset: function(changesetId, callback) {
+    _closeChangeset(changesetId, callback) {
         this._osmConnection.closeChangeset(changesetId, callback);
-    },
+    }
 
-    performOAuthSignIn: function(username, password, callback) {
-        this._osmConnection.requestOAuthToken(function(success) {
+    performOAuthSignIn(username, password, callback) {
+        this._osmConnection.requestOAuthToken((success) => {
             if (success)
                 this._onOAuthTokenRequested(username, password, callback);
             else
                 callback(false, null);
-        }.bind(this));
-    },
+        });
+    }
 
-    _onOAuthTokenRequested: function(username, password, callback) {
+    _onOAuthTokenRequested(username, password, callback) {
         /* keep track of authorizing username */
         this._username = username;
         this._osmConnection.authorizeOAuthToken(username, password, callback);
-    },
+    }
 
-    requestOAuthAccessToken: function(code, callback) {
-        this._osmConnection.requestOAuthAccessToken(code, (function(success, token) {
+    requestOAuthAccessToken(code, callback) {
+        this._osmConnection.requestOAuthAccessToken(code, (success, token) => {
             this._onOAuthAccessTokenRequested(success, callback);
-        }).bind(this));
-    },
+        });
+    }
 
-    _onOAuthAccessTokenRequested: function(success, callback) {
+    _onOAuthAccessTokenRequested(success, callback) {
         if (success) {
             this._isSignedIn = true;
             Application.settings.set('osm-username', this._username);
@@ -179,21 +173,21 @@ var OSMEdit = new Lang.Class({
         }
 
         callback(success);
-    },
+    }
 
-    signOut: function() {
+    signOut() {
         this._username = null;
         this._isSignedIn = false;
 
         Application.settings.set('osm-username', '');
         this._osmConnection.signOut();
-    },
+    }
 
     get isSignedIn() {
         return this._isSignedIn;
-    },
+    }
 
     get username() {
         return this._username;
     }
-});
+};
